@@ -24,7 +24,7 @@ from flashcam.v4lc import set_gem
 from flashcam.mmapwr import mmread_n_clear
 
 import os
-
+import sys
 
 # -----------------------------------------------------------------
 
@@ -50,9 +50,18 @@ class Camera(BaseCamera):
         res = config.CONFIG["resolution"]
         print("D... init_cam caleld with:", res )
         print("i... init_cam caleld with:", res )
+        print("D... init_cam caleld with:",  config.CONFIG["recommended"] )
+        print("i... init_cam caleld with:",  config.CONFIG["recommended"] )
 
-
+        # vids = []
+        # while len(vids)==0:
+        #     vids = recommend_video( config.CONFIG["recommended"]  )
+        #     if len(vids)==0:
+        #         print("!... NO VIDEO was recommended.",vids," sleeping 3 sec, locked in loop")
+        #         time.sleep(4)
+        #         # sys.exit()
         vids = recommend_video( config.CONFIG["recommended"]  )
+
         if len(vids)>0:
             vidnum = vids[0]
             cap = cv2.VideoCapture(vidnum,  cv2.CAP_V4L2)
@@ -63,6 +72,8 @@ class Camera(BaseCamera):
             # - it allowed to use try: except: and not stuck@!!!
             #cap = cv2.VideoCapture(vidnum)
             #   70% stucks even with timeout
+
+
             pixelformat = "MJPG"
             pixelformat = "YUYV"
             w,h =  int(res.split("x")[0]), int(res.split("x")[1])
@@ -126,7 +137,24 @@ class Camera(BaseCamera):
         fixed_image = None # just camera.
 
         camera = Camera(  )
-        cap, vidnum = camera.init_cam(  )
+        vidnum = None
+        while vidnum is None:
+            cap, vidnum = camera.init_cam(  )
+            if vidnum is None:
+                print("!... no video recommended, locked in a loop (realcam/frames)")
+                fullpath_fixed_image = "~/.config/flashcam/monoskop.jpg"
+                fullpath_fixed_image = os.path.expanduser( fullpath_fixed_image )
+                if os.path.exists(fullpath_fixed_image):
+                    frame = cv2.imread( fullpath_fixed_image)
+                    print(f"i...  {fullpath_fixed_image}")
+                    senh.add_frame(frame)
+                    senh.setbox(" ", senh.TIME)
+                    frame = senh.get_frame(  )
+                    # this is not giving anything
+                    yield frame
+                else:
+                    print(f"!... monoskop.jpg not found {fullpath_fixed_image}")
+                time.sleep(1)
 
         cc = v4lc.V4L2_CTL("/dev/video"+str(vidnum))
         capa = cc.get_capbilities()
@@ -332,7 +360,10 @@ class Camera(BaseCamera):
                     if gamma_multiply:
                         gamma_multiply = False
                         if "gamma" in capa:
-                            cc.set_gamma( int(gamma*2) )
+                            if gamma!=0:
+                                cc.set_gamma( int(gamma*2) )
+                            else:
+                                cc.set_gamma( int(1) )
                     if gamma_setdef:
                         gamma_setdef = False
                         if "gamma" in capa:
@@ -346,7 +377,10 @@ class Camera(BaseCamera):
                     if gain_multiply:
                         gain_multiply = False
                         if "gain" in capa:
-                            cc.set_gain( int(gain*2) )
+                            if gain!=0:
+                                cc.set_gain( int(gain*2) )
+                            else:
+                                cc.set_gain( int(1) )
                     if gain_setdef:
                         gain_setdef = False
                         if "gain" in capa:
@@ -364,7 +398,10 @@ class Camera(BaseCamera):
                         if "exposure_absolute" in capa:
                             cc.set_exposure_auto(1)
                             exposure_absolute = cc.get_exposure_absolute()
-                            cc.set_exposure_absolute( int(exposure_absolute*2) )
+                            if exposure_absolute!=0:
+                                cc.set_exposure_absolute( int(exposure_absolute*2) )
+                            else:
+                                cc.set_exposure_absolute( int(1) )
                     if expo_setdef:
                         expo_setdef = False
                         if "exposure_auto" in capa:
@@ -450,7 +487,9 @@ class Camera(BaseCamera):
 
     @staticmethod
     def set_video_source(source):
-
+        """
+        never user whatsoever !
+        """
         print("D... set_video_source: source=", source)
         camera = cv2.VideoCapture( source,  cv2.CAP_V4L2)
         print("D... ",camera)
