@@ -21,42 +21,35 @@ class Stream_Enhancer:
     ROW COLUMN  - colors defined elsewhere
    4 columns MAX
     """
-    TIME=(0,0) # gree
-
-    DISP=(0,4) # gree
-    MODE=(0,3) # red
+    # --------------- TOP  0,x
+    TIME  = (0,0) #
+    DISP  = (0,4) # gree
+    MODE  = (0,3) # red
     SUBBG = (0,5) # substract background
 
-    # lap   = (1,0)
-    # expo  = (3,0)
-    # gain  = (4,0)
-    # gamma = (5,0)
-    # speedx= (6,0)
-    # speedy= (7,0)
-    lap   = (1,0)
-    expo  = (2,1)
-    gain  = (2,2)
-    gamma = (2,3)
-    speedx= (2,4)
-    speedy= (2,5)
+    # ------------- LOW LINE
+    expo  = (2,0)
+    gain  = (2,1)
+    gamma = (2,2)
+    speedx= (2,3)
+    speedy= (2,4)
+    #--------------- NEVER when speedxy
+    dm=  (2,4) #  it is veeery long, overlaps
+
 
 
-    avi = (8,0) #
-    jpg = (9,0) #
 
     #--------------------- 2 is bottom
-    avg= (2,0) # accum
-
-    # blr= (2,1) #
-    # trh= (2,2) #
-    # hist=(2,3)
-    # dm=  (2,4) #  it is veeery long
-    blr =(2,0) #
-    trh =(3,0) #
-    hist=(4,0)
-    rot =(5,0)
-
-    dm=  (2,4) #  it is veeery long
+    lap = (1,0) # side
+    # avoid 2,0
+    avg = (3,0) # accum    2,0 is for LOWLINE
+    blr = (4,0) # LOW DEEP
+    trh = (5,0) # side
+    hist= (6,0) # side
+    rot = (7,0) # side  /otate in bin...
+    # ------ more (with/for uni)
+    avi = (8,0) #
+    jpg = (9,0) #
 
 
     delta_frame = None
@@ -167,6 +160,7 @@ class Stream_Enhancer:
             return False
         self.frame = image
         self.maxcol=5 # NORMALLY 4
+        # self.maxcol=7 # with x y
         self.maxrow=14
         # #if fontScale == 0.5
         #if w==320:
@@ -292,6 +286,8 @@ class Stream_Enhancer:
             return
 
         # manually I set leftside
+        # if (row==1)and(col==0):  side="left"
+        # if (row==2)and(col==0):  side="left" # low deck
         if (row==3)and(col==0):  side="left"
         if (row==4)and(col==0):  side="left"
         if (row==5)and(col==0):  side="left"
