@@ -520,6 +520,17 @@ def display2(videodev, save = False,
                 # time.sleep(0.2)
                 key = cv2.waitKey(1)
 
+                if (not frame is None) and (rpi_name!="") and (key == ord('h')):
+                    print("h PRESSED! - ")
+                    print("""
+ h ... show this help
+ a ... SAVING AVI
+ z ... stopping AVI
+ w ... openning web browser
+ s ... saving JPG
+ q ... quit
+""")
+
                 if (not frame is None) and (rpi_name!="") and (key == ord('w')):
                     print("W PRESSED! - openning web browser")
                     webbrowser.open( videodev.replace("/video","" ) ) # BRUTAL
