@@ -201,9 +201,12 @@ class V4L2_CTL():
 
         CMDL = ['v4l2-ctl', '-d', self.device, '-l']
         #print("i... ", CMDL )
-        output = sp.check_output( CMDL ).decode(
-            "utf-8")  # TODO: Check if the output is valid
-        #print(f"i... output = /{output}/")
+        output = ""
+        try:
+            output = sp.check_output( CMDL ).decode("utf-8")  # TODO: Check if the output is valid
+        except Exception as e:
+            print("!... Exception when", CMDL)
+    #print(f"i... output = /{output}/")
         if len(output) <2:
             #print("D... no output, returning")
             return []
